==> hopsparser-0.4.1.tar.gz: hopsparser-0.4.1/LICENCE.md <==
# Licence

## General licence

The following licence applies to all the files in this repository unless stated otherwise

Copyright 2020 Benoît Crabbé <benoit.crabbe@linguist.univ-paris-diderot.fr>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES
OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

## Licence exceptions

- [`hopsparser/conll2018_eval.py`](hopsparser/conll2018_eval.py) is taken from [the CoNLL 2018
  evaluation
  toolkit](https://github.com/ufal/conll2018/blob/37bc4d70bf415f188dc82a2e2600a38971d1137c/evaluation_script/conll18_ud_eval.py)
  and released under the terms of the [Mozilla Public v2.0](http://mozilla.org/MPL/2.0/), see its
  header for additional information.
- [`tests/fixtures/truncated-sv_talbanken-ud-dev.conllu`](tests/fixtures/truncated-sv_talbanken-ud-dev.conllu)
  is taken from Universal Dependencies 2.7 and released under the CC-BY-SA 4.0 International
  Licence, see [`tests/fixtures/README.md`](tests/fixtures/README.md) for the details.

==> hopsparser-0.7.0.tar.gz: hopsparser-0.7.0/LICENCE.md <==
# Licence

## General licence

The following licence applies to all the files in this repository unless stated otherwise

Copyright 2020 Benoît Crabbé <benoit.crabbe@linguist.univ-paris-diderot.fr>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES
OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

## Licence exceptions

- [`hopsparser/conll2018_eval.py`](hopsparser/conll2018_eval.py) is taken from [the CoNLL 2018
  evaluation
  toolkit](https://github.com/ufal/conll2018/blob/37bc4d70bf415f188dc82a2e2600a38971d1137c/evaluation_script/conll18_ud_eval.py)
  and released under the terms of the [Mozilla Public v2.0](http://mozilla.org/MPL/2.0/), see its
  header for additional information.
- [`tests/fixtures/truncated-sv_talbanken-ud.conllu`](tests/fixtures/truncated-sv_talbanken-ud.conllu)
  is taken from Universal Dependencies 2.10 and released under the CC-BY-SA 4.0
  International Licence, see [`tests/fixtures/README.md`](tests/fixtures/README.md) for the details.
